import Compressor from '@taro-hooks/compressorjs';
import { generateGeneralFail } from '../../utils/tool';
function _await(value, then, direct) {
  if (direct) {
    return then ? then(value) : value;
  }
  if (!value || !value.then) {
    value = Promise.resolve(value);
  }
  return then ? value.then(then) : value;
}
function _async(f) {
  return function () {
    for (var args = [], i = 0; i < arguments.length; i++) {
      args[i] = arguments[i];
    }
    try {
      return Promise.resolve(f.apply(this, args));
    } catch (e) {
      return Promise.reject(e);
    }
  };
}
function _catch(body, recover) {
  try {
    var result = body();
  } catch (e) {
    return recover(e);
  }
  if (result && result.then) {
    return result.then(void 0, recover);
  }
  return result;
}
function _invoke(body, then) {
  var result = body();
  if (result && result.then) {
    return result.then(then);
  }
  return then(result);
}
function checkBase64Prefix(url) {
  return url.startsWith('data:');
}
function dataURITOBlob(url) {
  var _mimeString$match;
  var _url$split = url.split(','),
    mimeString = _url$split[0],
    dataString = _url$split[1];
  var mime = mimeString == null ? void 0 : mimeString.match == null ? void 0 : (_mimeString$match = mimeString.match(/:(.*?);/)) == null ? void 0 : _mimeString$match[1];
  var length = dataString.length;
  var unitArray8 = new Uint8Array(length);
  while (length--) {
    unitArray8[length] = dataString.charCodeAt(length);
  }
  return new Blob([unitArray8], {
    type: mime
  });
}
export var downloadImage = _async(function (filePath) {
  return checkBase64Prefix(filePath) ? dataURITOBlob(filePath) : _await(fetch(filePath), function (responese) {
    return _await(responese.blob());
  });
});
export var generateBlobUrl = function generateBlobUrl(blob) {
  var blobInstance = new Blob([blob], {
    type: blob.type
  });
  var href = window.URL.createObjectURL(blobInstance);
  return href;
};
export var saveImageToPhotosAlbum = _async(function (_ref) {
  var _exit = false;
  var filePath = _ref.filePath,
    success = _ref.success,
    fail = _ref.fail;
  var failResult = generateGeneralFail('saveImageToPhotosAlbum');
  return _invoke(function () {
    if (filePath) {
      return _catch(function () {
        return _await(downloadImage(filePath), function (blob) {
          var href = generateBlobUrl(blob);
          var downloadElement = document.createElement('a');
          downloadElement.href = href;
          // base64 not have name, make random name
          downloadElement.download = Date.now() + '';
          document.body.appendChild(downloadElement);
          downloadElement.click();
          document.body.removeChild(downloadElement);
          window.URL.revokeObjectURL(href);
          var result = {
            errMsg: 'saveImageToPhotosAlbum: success'
          };
          success == null ? void 0 : success(result);
          _exit = true;
          return result;
        });
      }, function (e) {
        var withMessageFailResult = generateGeneralFail('saveImageToPhotosAlbum', e.message);
        fail == null ? void 0 : fail(withMessageFailResult);
        _exit = true;
        return withMessageFailResult;
      });
    }
  }, function (_result) {
    if (_exit) return _result;
    fail == null ? void 0 : fail(failResult);
    return failResult;
  });
});
/**
 * compressImage for h5
 * @param src source path
 * @param quality compress quality
 * @returns
 */
export var compressImage = _async(function (_ref2) {
  var src = _ref2.src,
    _ref2$quality = _ref2.quality,
    quality = _ref2$quality === void 0 ? 80 : _ref2$quality,
    _success = _ref2.success,
    fail = _ref2.fail;
  return _catch(function () {
    return _await(downloadImage(src), function (fileBlob) {
      var compress = new Promise(function (resolve, reject) {
        new Compressor(fileBlob, {
          quality: quality / 100,
          success: function success(res) {
            var tempFilePath = generateBlobUrl(res);
            var successResult = {
              tempFilePath: tempFilePath,
              errMsg: 'compressImage:ok'
            };
            _success == null ? void 0 : _success(successResult);
            resolve(successResult);
          },
          error: function error(e) {
            var failResult = generateGeneralFail('compressImage', e.message);
            fail == null ? void 0 : fail(failResult);
            reject(failResult);
          }
        });
      });
      return _await(compress);
    });
  }, function (e) {
    return generateGeneralFail('compressImage', e.errMsg || e.message);
  });
});