import { login as taroLogin, pluginLogin as taroPluginLogin, checkSession } from '@tarojs/taro';
import usePromise from '../usePromise';
import { generateGeneralFail } from '../utils/tool';
function _empty() {}
function _call(body, then, direct) {
  if (direct) {
    return then ? then(body()) : body();
  }
  try {
    var result = Promise.resolve(body());
    return then ? result.then(then) : result;
  } catch (e) {
    return Promise.reject(e);
  }
}
function _callIgnored(body, direct) {
  return _call(body, _empty, direct);
}
function _catch(body, recover) {
  try {
    var result = body();
  } catch (e) {
    return recover(e);
  }
  if (result && result.then) {
    return result.then(void 0, recover);
  }
  return result;
}
function _continueIgnored(value) {
  if (value && value.then) {
    return value.then(_empty);
  }
}
function _await(value, then, direct) {
  if (direct) {
    return then ? then(value) : value;
  }
  if (!value || !value.then) {
    value = Promise.resolve(value);
  }
  return then ? value.then(then) : value;
}
function _invoke(body, then) {
  var result = body();
  if (result && result.then) {
    return result.then(then);
  }
  return then(result);
}
function _async(f) {
  return function () {
    for (var args = [], i = 0; i < arguments.length; i++) {
      args[i] = arguments[i];
    }
    try {
      return Promise.resolve(f.apply(this, args));
    } catch (e) {
      return Promise.reject(e);
    }
  };
}
function useLogin() {
  var check = usePromise(checkSession);
  var loginAsync = usePromise(taroLogin);
  var pluginLoginAsync = usePromise(taroPluginLogin);
  var login = _async(function (needCheck, plugin, timeout) {
    var checkResult = !needCheck;
    return _invoke(function () {
      if (!checkResult) {
        return _continueIgnored(_catch(function () {
          return _callIgnored(check);
        }, function () {
          checkResult = false;
        }));
      }
    }, function () {
      var _exit = false;
      return _invoke(function () {
        if (!checkResult) {
          var payload = timeout ? {
            timeout: timeout
          } : {};
          return _await(plugin ? pluginLoginAsync(payload) : loginAsync(payload), function (_await) {
            _exit = true;
            return _await;
          });
        }
      }, function (_result) {
        return _exit ? _result : generateGeneralFail('login', 'code is valid, do not use fetch new one!');
      });
    });
  });
  return {
    check: check,
    login: login
  };
}
export default useLogin;